
from unittest.mock import patch
from odoo.tests import tagged
from odoo.addons.base.tests.common import HttpCaseWithUserPortal


@tagged('post_install', '-at_install')
class TestAccountingFirms(HttpCaseWithUserPortal):

    def test_01_accounting_firm_register(self):
        last_partner = self.env['res.partner'].search([], order='id DESC', limit=1)
        last_lead = self.env['crm.lead'].search([], order='id DESC', limit=1)

        self.start_tour('/', 'accounting_firm_register', login=None)

        new_partner = self.env['res.partner'].search([('id', '>', last_partner.id)])
        self.assertEqual(len(new_partner), 1, "A new partner should have been created")
        self.assertEqual(
            new_partner.portal_accounting_firm_level, '0_learning',
            "New accounting firms partner should be granted the 'Learning Partner' level",
        )
        new_lead = self.env['crm.lead'].search([('id', '>', last_lead.id)])
        self.assertEqual(len(new_lead), 1, "A new lead should have been created")

    def test_02_accounting_firm_register_bad_captcha(self):
        """Test that an error is shown when the captcha validation fails."""
        force_invalid_captcha = patch.object(
            self.env.registry['ir.http'], '_verify_request_recaptcha_token',
            return_value=False,
        )
        with force_invalid_captcha:
            self.start_tour('/', 'accounting_firm_register_bad_captcha', login=None)
